scipy.odr.Model
===============

.. currentmodule:: scipy.odr

.. autoclass:: Model

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Model.__init__
         Model.set_meta



   

